Data Digitizer 1.1.2 Release Note
===================================

Changes
------------
Minor fixes in documentation.

Download
---------------
`PyPI <https://pypi.org/project/datadigitizer/>`_


.. include:: 1.1.2-changelog.rst